import configparser
import re
import csv
import os
import json
import codecs
import numpy as np
import datetime
from tqdm import tqdm
import collections
import xlrd
import xlsxwriter


def read_config(conf_path):
    """
    根据配置文件的路径读取配置文件，并返回配置文件内容组成的dict
        配置文件格式：
            [conn_config]
            # sql连接配置
            host=172.19.50.66
            port=5432
            user=fpcdpc
            password=PASSWORD
            database=dpc_db
    :param conf_path: 配置文件路径
    :return: 配置文件组成的dict
    """
    conf_dict = {}
    cf = configparser.ConfigParser()
    cf.read(conf_path, encoding='utf-8')
    secs = cf.sections()
    for s in secs:
        items = cf.items(s)
        for i in items:
            conf_dict[i[0]] = i[1]
    return conf_dict


def check_and_creat_dir(file_url):
    '''
    判断文件目录是否存在，文件目录不存在则创建目录
    :param file_url: 文件路径，包含文件名
    :return:不存在则返回False， 存在True
    '''
    file_gang_list = file_url.split('/')
    if len(file_gang_list) > 1:
        [fname, fename] = os.path.split(file_url)
        print(fname, fename)
        if not os.path.exists(fname):
            os.makedirs(fname)
            return False
        else:
            return True
        # 还可以直接创建空文件

    else:
        return True



def getPolygonArea(points):
    """
    计算多边形面积
    :param points: [[x1, y1], [x2, y2], [x3, y3], [x4, y4], ...]
    :return: 面积
    """

    sizep = len(points)
    if sizep<3:
        return 0.0

    area = points[-1][0] * points[0][1] - points[0][0] * points[-1][1]
    for i in range(1, sizep):
        v = i - 1
        area += (points[v][0] * points[i][1])
        area -= (points[i][0] * points[v][1])

    return abs(0.5 * area)


def get_bracketed_content(text):
    """
    获取文本中所有小括号中的内容组成的list
    如：
        香港特(别行）政区（北京点）
        return：
            ['别行', '北京点']
    :param text: 文本
    :return: 括号中内容组成的list
    """
    res = re.findall(r'[（(](.*?)[）)]', text)
    return res


def rm_bracketed(text):
    """
    去除文本中的括号，包括括号中的内容，返回去括号后的文本
    如：
        香港特(别行）政区（北京点）
        return：
            香港特政区
    :param text:文本
    :return:去括号后的文本
    """
    res = re.sub(u"[（(](.*?)[）)]|\{.*?\}|\[.*?\]|\<.*?\>", "", text)
    return res


def rm_symbol(text):
    """
    去除文本中的所有符号，返回去符号后的文本
    如：
        香港特(别·行）政，区（北京-点）
        return：
            香港特别行政区北京点
    :param text:
    :return:
    """
    res = re.sub(
        "[\s+\.\!\/_, $%^*(+\"\')]|[ \t\r\n\\\\+—－\-()?【】“”！，。？:：、~@#￥%……&*（）\|「」▏·`▪•۰・●⁺°～’\[\➕;〔〕《–‖﹢〖〗‘》［］◆❤×『\]』｡×\\\️=；²∙﹙′★◎〉─③ⅳ―☆㎡〇ⅲ⊂♡⑧℃⑤︱╮₂ⅴⅱ³»①〈╭✘ ※❥･﹚､ⅰ<>›ܶ│丨‧丶]",
        "", text)
    return res


class MyEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, np.integer):
            return int(obj)
        elif isinstance(obj, np.floating):
            return float(obj)
        elif isinstance(obj, np.ndarray):
            return obj.tolist()
        elif isinstance(obj, bytes):
            return str(obj, encoding='utf-8')
        elif isinstance(obj, datetime.datetime):
            return obj.strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(obj, datetime.date):
            return obj.strftime('%Y-%m-%d')
        else:
            return super(MyEncoder, self).default(obj)

def write_json(filename, data, isIndent=False, isLine=False):
    """
    将字典或者list数据保存为json
    :param filename: 保存的文件名
    :param data: 要保存的数据
    :param isIndent: 是否按照漂亮的格式保存
    :param isLine: 是否按行保存
    :return:
    """
    if not isLine and (isinstance(data, dict) or isinstance(data, list)):
        if isIndent:
            json_str = json.dumps(data, ensure_ascii=False, indent=4, cls=MyEncoder)
            with open(filename, 'w', encoding='utf-8') as json_file:
                json_file.write(json_str)
        else:
            json_str = json.dumps(data, ensure_ascii=False, cls=MyEncoder)
            with open(filename, 'w', encoding='utf-8') as json_file:
                json_file.write(json_str)
    else:
        with codecs.open(filename, 'w', 'utf-8') as f:
            for formatted_instance in data:
                json_str = json.dumps(formatted_instance, ensure_ascii=False, cls=MyEncoder)
                f.write(json_str)
                f.write('\n')
        f.close()


def read_csv(file_path, isdict=False):
    """
    读取csv数据
    返回数据格式如：
        isdict=False（默认）：
            list，且每个元素也是list，每个元素表示每行数据
            [[line1_cell1, line1_cell2], [line2_cell1, line2_cell2], ...]
                例如：
                [
                    ['class','name','sex','height','year'],
                    [1,'xiaoming','male',168,23],
                    [2,'xiaohong','female',162,22],
                    [3,'xiaozhang','female',163,21],
                    [4,'xiaoli','male',158,21],
                    ...
                ]
        isdict=True：
            list，每个元素是dict，每个元素表示每行数据
            [{key1: line1_cell1, key2, line1_cell2, ...}, {key1: line2_cell1, key2, line2_cell2, ...}, ...]
                例如：
                [
                    {'class': '1', 'name': 'xiaoming', 'sex': 'male', 'height': '168', year: '23'},
                    {'class': '2', 'name': 'xiaohong', 'sex': 'female', 'height': '162', year: '22'},
                    {'class': '3', 'name': 'xiaozhang', 'sex': 'female', 'height': '163', year: '21'},
                    {'class': '4', 'name': 'xiaoli', 'sex': 'male', 'height': '158', year: '21'},
                    ...
                ]
    :param file_path:csv文件路径
    :param isdict: 返回数据格式，默认False， 返回的每行作为一个list， 如果设为True，则每行作为一个dict
    :return: list， 根据isdict觉得每个元素的格式
    """
    res = []
    with open(file_path, encoding='utf-8') as f:
        reader = csv.reader(f)
        try:
            for l in reader:
                if len(l) == 0:
                    continue
                res.append(l)
        except Exception as e:
            print("\033[1;31m 警告：读取csv时发生错误，已经读取到：{} 条数据， 错误内容： {}\033[0m".format(len(res), e))

    if isdict:
        if len(res) < 1:
            return []

        keys = []
        keys_dict = collections.defaultdict(int)
        for k in res[0]:
            k = str(k)
            keys_dict[k] += 1
            if k not in keys:
                keys.append(k)
            else:
                k_new = k + '_' + str(keys_dict[k])
                keys.append(k_new)

        res_dict = []
        for d in res[1:]:
            linei = {}
            for di, ki in zip(d, keys):
                linei[ki] = di
            res_dict.append(linei)

        return res_dict
    return res


def write_csv(filename, data):
    """
    将数据写到csv中
    支持两种数据格式：
        （1） list，且每个元素也是list，每个元素表示每行数据
            [[line1_cell1, line1_cell2], [line2_cell1, line2_cell2], ...]
        例如：
            [
                ['class','name','sex','height','year'],
                [1,'xiaoming','male',168,23],
                [2,'xiaohong','female',162,22],
                [3,'xiaozhang','female',163,21],
                [4,'xiaoli','male',158,21],
                ...
            ]

        （2） list，每个元素是dict，每个元素表示每行数据
            [{key1: line1_cell1, key2, line1_cell2, ...}, {key1: line2_cell1, key2, line2_cell2, ...}, ...]
        例如：
            [
                {'class': '1', 'name': 'xiaoming', 'sex': 'male', 'height': '168', year: '23'},
                {'class': '2', 'name': 'xiaohong', 'sex': 'female', 'height': '162', year: '22'},
                {'class': '3', 'name': 'xiaozhang', 'sex': 'female', 'height': '163', year: '21'},
                {'class': '4', 'name': 'xiaoli', 'sex': 'male', 'height': '158', year: '21'},
                ...
            ]
    :param filename: 需要写入的csv文件路径
    :param data: 需要写入的数据
    """
    isdict = False
    if len(data) > 0:
        if type(data[0]) == dict:
            isdict = True
    f = open(filename, 'w', encoding='utf-8', newline='')
    write_data = []
    keys = []
    if isdict:
        for d in data:
            keysi = list(d.keys())
            for ki in keysi:
                if ki not in keys:
                    keys.append(ki)

        write_data.append(keys)
        for d in data:
            di = []
            for k in keys:
                if k in d:
                    di.append(d[k])
                else:
                    di.append('')
            write_data.append(di)
    else:
        write_data = data
    writer = csv.writer(f)
    for i in write_data:
        writer.writerow(i)
    f.close()


def read_excel(filename, sheet_name='', isdict=False):
    """
    读取excel数据， 默认读取第一个sheet，可以通过sheet_name决定读取的sheet
    返回数据格式如：
        isdict=False（默认）：
            list，且每个元素也是list，每个元素表示每行数据
            [[line1_cell1, line1_cell2], [line2_cell1, line2_cell2], ...]
                例如：
                [
                    ['class','name','sex','height','year'],
                    [1,'xiaoming','male',168,23],
                    [2,'xiaohong','female',162,22],
                    [3,'xiaozhang','female',163,21],
                    [4,'xiaoli','male',158,21],
                    ...
                ]
        isdict=True：
            list，每个元素是dict，每个元素表示每行数据
            [{key1: line1_cell1, key2, line1_cell2, ...}, {key1: line2_cell1, key2, line2_cell2, ...}, ...]
                例如：
                [
                    {'class': '1', 'name': 'xiaoming', 'sex': 'male', 'height': '168', year: '23'},
                    {'class': '2', 'name': 'xiaohong', 'sex': 'female', 'height': '162', year: '22'},
                    {'class': '3', 'name': 'xiaozhang', 'sex': 'female', 'height': '163', year: '21'},
                    {'class': '4', 'name': 'xiaoli', 'sex': 'male', 'height': '158', year: '21'},
                    ...
                ]
    :param filename: excel文件路径
    :param sheet_name: 需要读取的excel中sheet的名称， 默认读取第一个sheet
    :param isdict: 返回数据格式，默认False， 返回的每行作为一个list， 如果设为True，则每行作为一个dict
    :return: list， 根据isdict觉得每个元素的格式
    """
    res = []

    data = xlrd.open_workbook(filename)

    if sheet_name != "":
        table = data.sheet_by_name(sheet_name)
    else:
        table = data.sheets()[0]

    rowNum = table.nrows
    colNum = table.ncols

    for i in range(rowNum):
        row_data = []
        for j in range(colNum):
            cell_ij = table.cell(i, j)

            value = table.cell(i, j).value
            if cell_ij.ctype == 4:
                if value == 1:
                    value = True
                else:
                    value = False

            if value == 'null':
                value = ''
            row_data.append(value)
        res.append(row_data)

    if isdict:
        if len(res) < 1:
            return None

        keys = []
        keys_dict = collections.defaultdict(int)
        for k in res[0]:
            k = str(k)
            keys_dict[k] += 1
            if k not in keys:
                keys.append(k)
            else:
                k_new = k + '_' + str(keys_dict[k])
                keys.append(k_new)

        res_dict = []
        for d in res[1:]:
            linei = {}
            for di, ki in zip(d, keys):
                linei[ki] = di
            res_dict.append(linei)

        return res_dict

    return res


def write_excel(filename, data, sheet_name='Sheet1'):
    """
    将数据写到excel中， 默认sheet_name='Sheet1'， 可以自行设置
    支持两种数据格式：
        （1） list，且每个元素也是list，每个元素表示每行数据
            [[line1_cell1, line1_cell2], [line2_cell1, line2_cell2], ...]
        例如：
            [
                ['class','name','sex','height','year'],
                [1,'xiaoming','male',168,23],
                [2,'xiaohong','female',162,22],
                [3,'xiaozhang','female',163,21],
                [4,'xiaoli','male',158,21],
                ...
            ]

        （2） list，每个元素是dict，每个元素表示每行数据
            [{key1: line1_cell1, key2, line1_cell2, ...}, {key1: line2_cell1, key2, line2_cell2, ...}, ...]
        例如：
            [
                {'class': '1', 'name': 'xiaoming', 'sex': 'male', 'height': '168', year: '23'},
                {'class': '2', 'name': 'xiaohong', 'sex': 'female', 'height': '162', year: '22'},
                {'class': '3', 'name': 'xiaozhang', 'sex': 'female', 'height': '163', year: '21'},
                {'class': '4', 'name': 'xiaoli', 'sex': 'male', 'height': '158', year: '21'},
                ...
            ]
    :param filename: 需要写入的excel文件路径， 如'a.xlsx'
    :param data: 需要写入的数据
    :param sheet_name: sheet的名称， 默认为：Sheet1
    """
    isdict = False
    if len(data) > 0:
        if type(data[0]) == dict:
            isdict = True
    workbook = xlsxwriter.Workbook(filename)  # 创建一个excel文件
    worksheet = workbook.add_worksheet(sheet_name)  # 在文件中创建一个名为TEST的sheet,不加名字默认为sheet1
    write_data = []
    keys = []
    if isdict:
        for d in data:
            keysi = list(d.keys())
            for ki in keysi:
                if ki not in keys:
                    keys.append(ki)

        write_data.append(keys)
        for d in data:
            di = []
            for k in keys:
                if k in d:
                    di.append(d[k])
                else:
                    di.append('')
            write_data.append(di)
    else:
        write_data = data

    if len(write_data) > 0:
        for i in range(len(write_data)):
            for j in range(len(write_data[i])):
                worksheet.write(i, j, write_data[i][j])

    workbook.close()


def compute_vecsimilar_one_2_one(veca, vecb):
    """
    计算一个向量和另一个向量之间的相似度
    :param veca: 第一个向量
    :param vecb: 第二个向量
    :return: 两个向量的相似度
    """
    veca = np.array(veca)
    vecb = np.array(vecb)
    veca = veca / (veca ** 2).sum() ** 0.5
    vecb = vecb / (vecb ** 2).sum() ** 0.5
    sim = (veca * vecb).sum()
    return sim


def compute_vecsimilar__one_2_many(veca, vecs):
    """
    计算一条数据和多个向量之间的相似度
    分别返回：
        最大相似度下标: maxarg
        最大相似度对应相似度：maxsim
    :param veca: vec
    :param vecs:[vec1, vec2, ...]
    :return:maxarg, maxsim
    """

    veca = np.array(veca)
    vecs = np.array(vecs)
    veca = veca / (veca ** 2).sum() ** 0.5
    vecs = vecs / (vecs ** 2).sum(axis=1, keepdims=True) ** 0.5

    sims = np.dot(veca, vecs.T)
    maxarg = sims.argmax()
    maxsim = max(sims)
    return maxarg, maxsim


def compute_vecsimilar__many_2_many(vecsa, vecsb):
    """
    计算多个向量和多个向量之间的相似度
    分别返回：
        maxarg： vecsa中的每条和vecsb中相似度最高的下标
        maxsim： vecsa中的每条和vecsb中相似度最高的相似度
    :param vecsa:[vec1, vec2, ...]
    :param vecsb:[vec1, vec2, ...]
    :return:maxargs, maxsims
    """
    veca = np.array(vecsa)
    vecs = np.array(vecsb)
    veca = veca / (veca ** 2).sum(axis=1, keepdims=True) ** 0.5
    vecs = vecs / (vecs ** 2).sum(axis=1, keepdims=True) ** 0.5

    sims = np.dot(veca, vecs.T)

    maxargs = sims.argmax(1)
    maxsims = sims.max(1)
    return maxargs, maxsims

def LCS(x, y):
    c = np.zeros((len(x)+1, len(y)+1))
    b = np.zeros((len(x)+1, len(y)+1))
    for i in range(1, len(x)+1):
        for j in range(1, len(y)+1):
            if x[i-1] == y[j-1]:
                c[i, j] = c[i-1, j-1]+1
                b[i, j] = 2
            else:
                if c[i-1, j] >= c[i, j-1]:
                    c[i, j] = c[i-1, j]
                    b[i, j] = 1
                else:
                    c[i, j] = c[i, j-1]
                    b[i, j] = 3
    return c, b


def getLCS(texta, textb):
    """
    获取最长公共序列
    如：
        x = '荣丰控股集团股份有限公司'
        y = '荣丰（天津）医疗器械有限公司'
    return:
        荣丰有限公司
    :param x:
    :param y:
    :return:
    """
    c, b = LCS(texta, textb)
    i = len(texta)
    j = len(textb)
    lcs = ''
    while i > 0 and j > 0:
        if b[i][j] == 2:
            lcs = texta[i-1]+lcs
            i -= 1
            j -= 1
        if b[i][j] == 1:
            i -= 1
        if b[i][j] == 3:
            j -= 1
        if b[i][j] == 0:
            break
    return lcs


#! -*- coding:utf-8 -*-
import os
import fairies as fa
from xpinyin import Pinyin
import re
# import pylcs
from navinfo_tool import utils
import collections
from tqdm import tqdm
from navinfo_tool import end_words, same_stroke

# end_words_path = os.path.abspath(os.path.join(os.path.abspath(os.path.dirname(__file__)), "./data_strengthen/end_words.txt"))
# same_stroke_path = os.path.abspath(os.path.join(os.path.abspath(os.path.dirname(__file__)), "./data_strengthen/same_stroke.json"))

# 结尾关键词
common_words = end_words.end_words

pinyin = Pinyin()
# def read_end_words():
#     ends = []
#     with open(end_words_path, encoding='utf-8') as f:
#         lines = f.readlines()
#         for l in lines:
#             l = l.strip()
#             if len(l) > 0:
#                 ends.append(l)
#     return ends
# common_words = read_end_words()


# 形似字
same_stroke = same_stroke.same_stroke
same_stroke_dict = collections.defaultdict(list)
for strokes in same_stroke:
    strokes = list(strokes)
    for s in strokes:
        for sc in strokes:
            if sc != s and sc not in same_stroke_dict[s]:
                same_stroke_dict[s].append(sc)

sameinone = ["烧烤", "木材", "疼痛", "鲜羊", "鲜鱼", "翻羽", "景京", "林村", "马驰", "检验", "酿酒", "配酒", "酒西", "百北",
             "板饭", "月育", "份分", "大夫", "大六", "大天", "林木", "动力", "科料", "起超", "股投", "山技", "星家", "设投",
             "元园", "运动", "阁门", "林材"]

def rm_common_words(text, common_words):
    """去除结尾"""
    for cw in common_words:
        if text.endswith(cw):
            text = re.sub(cw, '', text)
    return text

def subdu(text):
    """将°C换为度"""
    if re.findall('[0-9]+[°度][Cc]*', text):
        text = re.sub('[°度][Cc]*', '度', text)
    return text

def strQ2B(ustring):
    """全角转半角"""
    rstring = ""
    for uchar in ustring:
        inside_code=ord(uchar)
        if inside_code == 12288:                              #全角空格直接转换
            inside_code = 32
        elif (inside_code >= 65281 and inside_code <= 65374): #全角字符（除空格）根据关系转化
            inside_code -= 65248

        rstring += chr(inside_code)
    return rstring

def bignum2num(text):
    """大写转小写"""
    chinese_num = {'零': 0, '壹': 1, '贰': 2, '叁': 3, '肆': 4, '伍': 5, '陆': 6, '柒': 7, '捌': 8, '玖': 9, '一': 1, '二': 2, '三': 3, '四': 4, '五': 5, '六': 6, '七': 7, '八': 8, '九': 9}
    text = list(text)
    for c in chinese_num:
        while c in text:
            text[text.index(c)] = str(chinese_num[c])
    return ''.join(text)

def convertStrToPinyin(text):
    """获取文本对应的拼音list"""
    res = pinyin.get_pinyin(text, ' ')
    return res.split(' ')

def find_disorder(text_list):
    """查找是否有倒序错误"""
    texts = [t for t in text_list if len(t) > 0]
    if len(texts) <= 1:
        return {}
    cl = len(texts)
    flaga = False
    flagb = False
    rstr = ''
    prstr = ''
    for i in range(cl-1):
        for j in range(i+1, cl):
            a = texts[i]
            b = texts[j]
            if a == b:
                continue
            if len(a) > len(b):
                a, b = b, a

            # coml = pylcs.lcs(a, b)
            coml = len(utils.getLCS(a, b))

            reversestr = ''
            preversestr = ''
            maxcoml = coml
            for window in range(2, 5):
                if len(a) >= window:
                    for start in range(len(a) - window + 1):
                        reversea = a[:start] + ''.join(list(reversed(a[start: start + window]))) + a[start + window:]
                        # revcomlen = pylcs.lcs(reversea, b)
                        revcomlen = len(utils.getLCS(reversea, b))
                        if revcomlen > maxcoml:
                            maxcoml = revcomlen
                            flagb = True
                            preversestr = a[start: start + window]
                        tmpreverse = ''.join(list(reversed(a[start: start + window])))
                        if tmpreverse in b and len(tmpreverse) > len(reversestr):
                            if tmpreverse != ''.join(list(reversed(tmpreverse))):
                                reversestr = tmpreverse
                                flaga = True


            if flaga and len(reversestr) > len(rstr):
                rstr = reversestr
            if flagb and len(preversestr) > len(prstr):
                prstr = preversestr
    if flaga and flagb and (rstr == prstr or ''.join(list(reversed(rstr))) == prstr):
        rt = rstr
        urt = ''.join(list(reversed(rt)))


        if re.findall('[a-zA-Z]', rstr):
            if len(rt) == 2 and len(re.sub('[a-zA-Z]', '', rt)) == 0:
                return {}
            ents = [(''.join(re.findall(r'[A-Za-z]', t))).lower() for t in texts]
            if rstr not in ents:
                return {}

        if re.findall('[0-9]', rstr):
            return {}

        if re.findall('[东南西北]', rstr):
            if len(re.sub('[东南西北]', '', rstr)) <= 1:
                return ''

        flagallin = False
        for t in text_list:
            if rt in t and urt in t:
                if t.index(rt) - t.index(urt) > 1 or t.index(rt) - t.index(urt) < -1:
                    flagallin = True

        if flagallin:
            return {}

        comw = ['胎', '发', '印', '粮', '家', '祛', '地', '米', '纹', '食', '雷', '手', '烤', '具', '衣', '皮', '章',
                '蹄', '砂', '服', '国', '垫', '彩', '机', '腾', '球', '画', '田', '锁', '果', '海', '邮', '洗', '美',
                '饼', '暖', '生', '车', '区', '品', '炒', '壁', '村', '加', '灸', '修', '鞋', '汽', '租', '电', '摄',
                '艺', '墙', '名', '童', '装', '磨', '油', '羊', '多', '出', '房', '餐', '凉', '肉', '养', '专', '花',
                '柜', '桃', '渔', '寿', '牛', '活', '布', '子']
        flaglr = False
        if len(rstr) == 3 and rstr[1] in comw:
            lrt = rt[1] + rt
            rrt = rt + rt[1]
            for t in texts:
                if lrt in t or rrt in t:
                    flaglr = True
        if flaglr:
            return {}

        if not (rt in texts or urt in texts):
            lwords = set()
            rwords = set()
            for t in texts:
                if not (rt in t and urt in t):
                    if rt in t:
                        idx = t.index(rt)
                        if idx != 0:
                            lwords.add(t[idx - 1])
                        if idx != len(t) - len(rt):
                            rwords.add(t[idx + len(rt)])
                    if urt in t:
                        idx = t.index(urt)
                        if idx != 0:
                            lwords.add(t[idx - 1])
                        if idx != len(t) - len(urt):
                            rwords.add(t[idx + len(urt)])
            if len(lwords) > 1 or len(rwords) > 1 and len(rt) == 2:
                return {}
            if len(lwords) > 1 or len(rwords) > 1 and len(rt) > 2:
                return {}

        res = {}
        for t in texts:
            if rt in t:
                res[t] = (rt, rt, t.index(rt))
            if urt in t:
                res[t] = (urt, urt, t.index(urt))
        return res
    else:
        return {}


def find_sames(text1, text2):
    """查找是否有同形错误"""
    if text1 == text2:
        return []
    if not fa.is_chinese(text1) and not fa.is_chinese(text2):
        return []
    if len(text1) > len(text2):
        text1, text2 = text2, text1
    if len(text1) < 2:
        return []

    # 用来保存同型的文本
    txtexts = []

    # 遍历text1
    for i in range(len(text1)):
        word = text1[i]
        if word in same_stroke_dict:
            word_sames = same_stroke_dict[word]
            for ws in word_sames:
                if ws in text2:
                    wsidx = text2.index(ws)
                    if i == 0:
                        if wsidx != len(text2)-1:
                            if text1[i + 1] == text2[wsidx + 1]:
                                txtexts.append(tuple(sorted([(word, i), (ws, wsidx)], key=lambda x: x[0])))
                    elif i == len(text1) - 1:
                        if wsidx != 0:
                            if text1[i - 1] == text2[wsidx - 1]:
                                txtexts.append(tuple(sorted([(word, i), (ws, wsidx)], key=lambda x: x[0])))
                    else:
                        pre = ''
                        suf = ''
                        if wsidx == 0:
                            suf = text2[wsidx + 1]
                        elif wsidx == len(text2)-1:
                            pre = text2[wsidx - 1]
                        else:
                            pre = text2[wsidx - 1]
                            suf = text2[wsidx + 1]
                        if text1[i-1] == pre or text1[i+1] == suf:
                            txtexts.append(tuple(sorted([(word, i), (ws, wsidx)], key=lambda x: x[0])))
    if len(txtexts) > 0:
        txtexts = txtexts[0]
    return txtexts

def find_tongxing(text_list):
    """查找是否有同形错误"""
    texts = [t for t in text_list if len(t) > 0]
    res_d = {}
    # 要输出span 和具体到字 一样多不确定
    res = []
    for i in range(len(texts) - 1):
        for j in range(i + 1, len(texts)):
            if texts[i] != texts[j]:
                answer = find_sames(texts[i], texts[j])
                if len(answer) > 0:
                    res.append(answer)

    res_idx = list(set(res))
    res = set()
    for r in res_idx:
        res.add((r[0][0], r[1][0]))
    res = list(res)

    if len(res) > 0:
        rmr = []
        for r in res:
            for t in texts:
                if r[0] in t and r[1] in t:
                    if ''.join(r) in sameinone or ''.join([r[1], r[0]]) in sameinone:
                        rmr.append(r)
        rmr = list(set(rmr))
        for r in rmr:
            res.remove(r)

        rmr = []
        for r in res:
            for t in texts:
                if r[0] in t and r[1] in t:
                    r0idx = t.index(r[0])
                    r1idx = t.index(r[1])
                    pre0 = t[r0idx - 1] if r0idx > 0 else ''
                    pre1 = t[r1idx - 1] if r1idx > 0 else ''
                    sub0 = t[r0idx + 1] if r0idx < len(t) - 1 else ''
                    sub1 = t[r1idx + 1] if r1idx < len(t) - 1 else ''
                    if pre0 == pre1 or sub0 == sub1:
                        rmr.append(r)
        rmr = list(set(rmr))
        for r in rmr:
            res.remove(r)

        if len(res) > 0:

            for ri in res_idx:
                if ri[0][0] == res[0][0] and ri[1][0] == res[0][1]:
                    for t in text_list:
                        if len(t) > ri[0][1] and t[ri[0][1]] == ri[0][0]:
                            res_d[t] = (res[0][0], res[0][0], t.index(res[0][0]))
                        if len(t) > ri[1][1] and t[ri[1][1]] == ri[1][0]:
                            res_d[t] = (res[0][1], res[0][1], t.index(res[0][1]))
                    break
            return res_d

    return res_d


def compare_tongyin(text1, text2):
    """查找是否有同音错误"""
    # text1作为短文本
    if len(text1) > len(text2):
        text1, text2 = text2, text1
    # text1和text2拼音list
    text1_py = convertStrToPinyin(text1)
    text2_py = convertStrToPinyin(text2)
    # text2拼音组成的字符串
    text2_py_str = ''.join(text2_py)
    # text2拼音字符串对应每个文本的开始位置
    text2_py_idx = [0]
    for tp in text2_py:
        text2_py_idx.append(text2_py_idx[-1] + len(tp))

    # 如果只有一个字，则过滤
    if len(text1) < 2:
        return []

    # 用来保存同音的文本
    tytexts = []
    # 每两个字判断是否有同音
    flaga = False
    # 每三个字判断是否有同音
    flagb = False
    flagstart = False
    for i in range(len(text1) - 1):
        tmp = text1[i: i + 2]
        tmp_py = ''.join(text1_py[i: i + 2])
        if len(tmp_py) > 0 and tmp_py in text2_py_str and tmp not in text2:
            t2pystart = text2_py_str.index(tmp_py)
            if t2pystart in text2_py_idx:
                t2start = text2_py_idx.index(t2pystart)
                if (len(''.join(text2_py[t2start: t2start + len(tmp)])) - len(tmp_py)) <= 1:
                    t2tmp = text2[t2start: t2start + 2]
                    repeats = sorted([tmp, t2tmp])
                    tytexts.append(tuple(repeats))
                    flaga = True
        elif len(tmp_py) > 0 and (re.sub('un', 'ong', tmp_py) in text2_py_str or re.sub('ong', 'un',
                                                                                        tmp_py) in text2_py_str) and tmp not in text2:
            if re.sub('un', 'ong', tmp_py) in text2_py_str:
                t2pystart = text2_py_str.index(re.sub('un', 'ong', tmp_py))
            else:
                t2pystart = text2_py_str.index(re.sub('ong', 'un', tmp_py))
            if t2pystart in text2_py_idx:
                t2start = text2_py_idx.index(t2pystart)
                if (len(''.join(text2_py[t2start: t2start + len(tmp)])) - len(tmp_py)) <= 1:
                    flaga = True

    if len(text1) > 2:
        for i in range(len(text1) - 2):
            tmp = text1[i: i + 3]
            tmp_py = ''.join(text1_py[i: i + 3])
            if len(tmp_py) > 0 and tmp_py in text2_py_str and tmp not in text2:
                t2pystart = text2_py_str.index(tmp_py)
                if t2pystart in text2_py_idx:
                    t2start = text2_py_idx.index(t2pystart)
                    if (len(''.join(text2_py[t2start: t2start + len(tmp)])) - len(tmp_py)) <= 1:
                        t2tmp = text2[t2start: t2start + 2]
                        repeats = sorted([tmp, t2tmp])
                        flagb = True
            elif len(tmp_py) > 0 and (re.sub('un', 'ong', tmp_py) in text2_py_str or re.sub('ong', 'un',
                                                                                            tmp_py) in text2_py_str) and tmp not in text2:
                if re.sub('un', 'ong', tmp_py) in text2_py_str:
                    t2pystart = text2_py_str.index(re.sub('un', 'ong', tmp_py))
                else:
                    t2pystart = text2_py_str.index(re.sub('ong', 'un', tmp_py))
                if t2pystart in text2_py_idx:
                    t2start = text2_py_idx.index(t2pystart)
                    if (len(''.join(text2_py[t2start: t2start + len(tmp)])) - len(tmp_py)) <= 1:
                        flagb = True
    else:
        flagb = True

    if flaga and flagb:
        return tytexts
    else:
        return []

def find_tongyin(text_list):
    """查找是否有同音错误"""
    texts = [re.sub("[a-zA-Z0-9]", '', t) for t in text_list]
    texts = [t for t in texts if len(t) > 0]
    # 遍历获取所有的同音不同形的两字
    res = []
    if len(texts) > 1:
        for i in range(len(texts) - 1):
            for j in range(i + 1, len(texts)):
                if texts[i] != texts[j]:
                    add = compare_tongyin(texts[i], texts[j])
                    if len(add) > 0:
                        res.extend(add)

    res = list(set(res))
    if len(res) == 0:
        return {}

    r = res[0]

    # 保存错误的字和对应正确的字
    errorwords = []

    # 获取公共字，即非错误的字
    publicword = list(set(r[0]).intersection(set(r[1])))
    # 如果没有公共字，则不处理
    if len(publicword) == 0:
        return {}
    # 去掉公共字
    lr0 = list(r[0])
    lr1 = list(r[1])
    for c in publicword:
        while c in lr0:
            lr0.remove(c)
        while c in lr1:
            lr1.remove(c)
    # 如果去完公共字后长度不为1，则不处理
    if len(lr0) != 1 or len(lr1) != 1:
        return {}

    errwords = [''.join(lr0), ''.join(lr1)]

    # 如果common_words同时在文本中，则过滤
    flagws0 = False
    flagws1 = False
    common_words = [('陕西', '山西'), ('公司', '工程'), ('公厕', '公共'), ('家具', '家居'), ('民宿', '民俗')]
    common_word = ["电店", "厂场", "务屋", "具居", "一壹", "二贰", "三叁", "四肆", "五伍", "六陆", "七柒", "八捌", "九玖", "十拾", "定订", "潢璜", "器气", "厨橱", "手授", "喜囍", "坊房"]
    for cws in common_words:
        if (errwords[0] in cws[0] and errwords[1] in cws[1]) or (errwords[1] in cws[0] and errwords[0] in cws[1]):
            for t in texts:
                if cws[0] in t:
                    flagws0 = True
                if cws[1] in t:
                    flagws1 = True
    if flagws0 and flagws1:
        return {}
    # 如果common_word同时在文本中，则过滤
    flagw = False
    for cw in common_word:
        if errwords[0] in cw and errwords[1] in cw:
            flagw = True
            break
    if flagw:
        return {}

    # 如果两个字的拼音相差太远，则不处理
    flag = False
    for er0, er1 in zip(lr0, lr1):
        er0p = convertStrToPinyin(er0)[0]
        er1p = convertStrToPinyin(er1)[0]
        if er0p != er1p and (len(er0p)<3 or len(er1p) < 3 or 'a' in er0p or 'a' in er1p or 'u' in er0p or er0p[0] != er1p[0]):
            flag = True
            continue
    if flag:
        return {}

    # 如果和前面处理的错字相同，则不处理
    if tuple(errwords) in errorwords or tuple(reversed(errwords)) in errorwords:
        return {}
    errorwords.append(errwords)

    # 如果错字数量大于1，判断是否相邻，如果相邻则组合
    if len(errorwords) > 1:
        errws = ''.join([e[0] for e in errorwords])
        if len(texts) > 0:
            for t in texts:
                if errws in t:
                    errorwords = [[''.join([e[0] for e in errorwords]), ''.join([e[1] for e in errorwords])]]
                if ''.join(list(reversed(errws))) in t:
                    errorwords = [[''.join(list(reversed([e[0] for e in errorwords]))), ''.join(list(reversed([e[1] for e in errorwords])))]]

    res_d = {}
    if len(errorwords) > 0:
        for t in text_list:
            if r[0] in t:
                res_d[t] = (errorwords[0][0], errorwords[0][0], t.index(r[0]) + r[0].index(errorwords[0][0]))
            if r[1] in t:
                res_d[t] = (errorwords[0][1], errorwords[0][1], t.index(r[1]) + r[1].index(errorwords[0][1]))
        return res_d

    return res_d


def is_common_sequence(sub, text, diff_span=1):
    """
        判断是否满足1个字区别的共同子序列
        sub 来自其他字符串的子序列
        text 目标字符串
        diff_span 差异跨度

    """
    while sub[0] in text:

        wrong_text, diff = '', 0
        temp_text = text[text.find(sub[0]) + 1:]
        start = text.find(sub[0])
        end = start
        for i, s in enumerate(sub[1:]):
            if temp_text != '' and s == temp_text[0]:
                if diff == diff_span:
                    if text.count(sub[0]) > 1:
                        break
                    else:
                        dif_res = text[start:end]
                        for s in sub:
                            if s not in dif_res:
                                dif_res += s
                        if dif_res in text:
                            return False, sub, wrong_text, dif_res

                temp_text = temp_text[1:]
                end += 1
            elif len(temp_text) > 1 and s == temp_text[1]:

                if i != len(sub[1:]) - 1:
                    diff += 1
                wrong_text = temp_text[0]
                temp_text = temp_text[2:]
                end += 2

                if diff > diff_span:
                    break
            else:
                break
            if i == len(sub[1:]) - 1 and diff == diff_span:
                dif_res = text[start:end]
                for s in sub:
                    if s not in dif_res:
                        dif_res += s
                    if dif_res in text:
                        return False, sub, wrong_text, dif_res
                return False, sub, wrong_text, dif_res
        text = text[text.find(sub[0]) + 1:]
    return True, '', '', ''


def find_same_span(text1, text2):
    num = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0']
    alpha = 'abcdefghijklmnopqrestuvwxwz'
    stop_words = ['省', '市', '县', '区', '镇', '路', '村', '院', '站', '东', '南', '西', '北', '修']
    first_stop = ["大", "术", "学", "员", "第", "新", "老", "和", "城", "部", "园", "总", "的", "国", "业", "分", "理", "与", "鲜", "中",
                  "楼", "店", "号", "车", "肉", "房", "金", "医", "局", "风", "大", "术", "学", "员", "第", "新", "老", "和", "城", "部",
                  "园", "总", "的", "国", "业", "分", "理", "与", "鲜", "中", "楼", "店", "号", "车", "肉", "房", "金", "医", "局", "风",
                  "式", "党", "街", "售", "料", "馆", "易", "障", "杀", "里", "道", "の", "电", "委", "社", "度", "菜", "童", "会", "水",
                  "甲", "蹈", "乡", "桥", "展", "际", "茶", "下", "生", "育", "牌", "门", "钢", "务", "加", "名", "羊", "蔬", "师", "器"]

    # 如果字符串中不包含中文则不寻找
    if not fa.is_chinese(text1) and not fa.is_chinese(text2):
        return True, '', '', ''

    if text1 == text2:
        return True, '', '', ''

    if len(text1) > len(text2):
        long, short = text1, text2
    else:
        long, short = text2, text1

    if short in long:

        """
            解决(哈哈,哈哈哈哈)
                (悠土鸡蛋直销 土鸡蛋直销)
                (烘焙坊 1烘焙坊)
        """

        if short == long[:len(short)]:
            return True, '', '', ''

    if len(short) + 1 == len(long):
        for position,i in enumerate(long):
            new = long.replace(i,'')

            if short == new and i not in stop_words and i not in first_stop and i not in num:
                if position < 3:
                    temp_long = long[:position+3]
                elif position > len(long)-2:
                    temp_long = long[position-3:]
                else:
                    temp_long = long[position-2:position+2]

                if len(temp_long) > 3:
                    temp_short = temp_long.replace(i,'')
                    return False, temp_short, i, temp_long

    for i in range(len(short)):
        for j in range(i + 1, len(short) + 1):
            if short[i:j] not in long:
                # 在这里限制前后的相同的长度 前2后1 或者前1后2等
                if (short[i:j][:2] in long and short[i:j][-1:] in long) or (
                        short[i:j][:1] in long and short[i:j][-2:] in long):
                    res, keyword, text, dif_res = is_common_sequence(short[i:j], long)
                    if not res:

                        if text in stop_words:
                            return True, '', '', ''

                        # 只有在开头的保留 其他的去掉
                        if text in first_stop:
                            if text1[0] == text or text2[0] == text:
                                return res, keyword, text, dif_res
                            else:
                                return True, '', '', ''

                        # 去掉不在开头的数字
                        if text in num:
                            if text1[0] not in num or text2[0] not in num:
                                return True, '', '', ''
                        elif text in alpha:
                            if text1[0] in alpha or text2[0] in alpha:
                                return True, '', '', ''
                            elif text in text1 and text1[-1] != text and text in text2 and text2[-1] != text:
                                if (text1[text1.find(text) - 1] not in alpha and text1[
                                    text1.find(text) + 1] not in alpha) or (
                                        text2[text2.find(text) - 1] not in alpha and text2[text2.find(text) + 1] not in alpha):
                                    return res, keyword, text, dif_res
                            else:
                                return True, '', '', ''

                        jieba_list = fa.jieba_cut(short)
                        isLegal = False
                        for k in range(len(jieba_list)):
                            if k != len(jieba_list) - 1:
                                temp = jieba_list[k] + jieba_list[k + 1]
                                if short[i:j] == temp:
                                    isLegal = True
                                    break
                        if not isLegal:
                            continue

                        return res, keyword, text, dif_res

    long, short = short, long
    for i in range(len(short)):
        for j in range(i + 1, len(short) + 1):
            if short[i:j] not in long:
                # 在这里限制前后的相同的长度 前2后1 或者前1后2等
                if (short[i:j][:2] in long and short[i:j][-1:] in long) or (
                        short[i:j][:1] in long and short[i:j][-2:] in long):
                    res, keyword, text, dif_res = is_common_sequence(short[i:j], long)
                    if not res:

                        if text in stop_words:
                            return True, '', '', ''

                        # 去掉不在开头的数字
                        if text in first_stop:
                            if text1[0] == text or text2[0] == text:
                                return res, keyword, text, dif_res
                            else:
                                return True, '', '', ''

                        if text in num:
                            if text1[0] not in num or text2[0] not in num:
                                return True, '', '', ''
                        elif text in alpha:
                            if text1[0] in alpha or text2[0] in alpha:
                                return True, '', '', ''
                            elif text in text1 and text1[-1] != text and text in text2 and text2[-1] != text:
                                if (text1[text1.find(text) - 1] not in alpha and text1[
                                    text1.find(text) + 1] not in alpha) or (
                                        text2[text2.find(text) - 1] not in alpha and text2[text2.find(text) + 1] not in alpha):
                                    return res, keyword, text, dif_res
                            else:
                                return True, '', '', ''

                        jieba_list = fa.jieba_cut(short)
                        isLegal = False
                        for k in range(len(jieba_list)):
                            if k != len(jieba_list) - 1:
                                temp = jieba_list[k] + jieba_list[k + 1]
                                if short[i:j] == temp:
                                    isLegal = True
                                    break
                        if not isLegal:
                            continue
                        return res, keyword, text, dif_res

    long, short = short, long

    if short[1:3] == long[:2] and short[:2] != long[:2]:
        if short[0] not in stop_words:
            return False, short[:3], short[0], long[:2]
    if long[1:3] == short[:2] and long[:2] != short[:2]:
        if long[0] not in stop_words:
            return False, long[:3], long[0], short[:2]

    return True, '', '', ''


def find_moreless(text1, text2):
    """查找是否有多字少字错误"""
    ds_dict = {}
    res, keyword, text, dif_res = find_same_span(text1, text2)
    if len(keyword) > len(dif_res):
        keyword, dif_res = dif_res, keyword
    if not res:
        ds_dict = {}
        if dif_res in text1:
            ds_dict[text1] = (text, dif_res, text1.find(dif_res))
            ds_dict[text2] = ('', keyword, text2.find(keyword))
        else:
            ds_dict[text1] = ('', keyword, text1.find(keyword))
            ds_dict[text2] = (text, dif_res, text2.find(dif_res))
    return ds_dict


def find_typo(text1, text2):
    """查找是否有错字错误"""
    if not fa.is_chinese(text1) and not fa.is_chinese(text2):
        return {}
    if len(text1) > len(text2):
        text1, text2 = text2, text1
    if len(text1) < 3:
        return {}

    prenum = 2
    subnum = 2

    # 用来保存错别字
    typowords = []
    if len(text1) == 3 and len(text2) == 3:
        eqnum = 0
        uneqwords = []
        for t1w, t2w in zip(text1, text2):
            if t1w == t2w:
                eqnum += 1
            else:
                uneqwords.append([(t1w, text1), (t2w, text2)])
        if eqnum == 2:
            typowords.extend(uneqwords)
    elif len(text1) == 4 and len(text2) == 4:
        eqnum = 0
        uneqwords = []
        for t1w, t2w in zip(text1, text2):
            if t1w == t2w:
                eqnum += 1
            else:
                uneqwords.append([(t1w, text1), (t2w, text2)])
        if eqnum == 3:
            typowords.extend(uneqwords)
    elif len(text1) >= prenum + subnum + 1:
        flag = True
        for i in range(len(text1) - prenum - subnum):
            if flag:
                t1tmp = text1[i: i + prenum + subnum + 1]
                for j in range(len(text2) - prenum - subnum):
                    t2tmp = text2[j: j + prenum + subnum + 1]
                    eqnum = 0
                    uneqidx = 0
                    uneqwords = []
                    for idx, (t1w, t2w) in enumerate(zip(t1tmp, t2tmp)):
                        if t1w == t2w:
                            eqnum += 1
                        else:
                            uneqwords.append([(t1w, t1tmp), (t2w, t2tmp)])
                            uneqidx = idx
                    if eqnum == prenum + subnum and uneqidx >= 1 and uneqidx <= 3:
                        typowords.extend(uneqwords)
                        flag = False
                        break

    exclude_words = '东西南北小城村区大的电儿一二三四五六七八九发服分社美睫甲乙服汽京业上下家学政营卖容面国路街桥园校厦修饰车开换直地洗海保出入生院山人处の分解维部水县里鲜商乐篮活体配务技男女工产媒播前后所馆侧旁边外内贸民房利居烫楼扶庆披比食管烧烤动酒饭住农式会市网动足门公养菜蔬快画热暖际板装钢验刘李张赵果墙壁初高陈王郭纪料线衣展宾旅猫孕狗店孙牛羊鸭接招康恢药魏定订镇乡寺母器杂坊私行材肉具讯潢璜喜囍厨橱'

    res_d = {}
    if len(typowords) > 0:
        res_typo = typowords[0]
        wss = res_typo[0][0] + res_typo[1][0]
        if re.findall('[a-zA-Z0-9]', wss):
            return res_d
        for ew in exclude_words:
            if ew in wss:
                return res_d
        res_d[text1] = (res_typo[0][0], res_typo[0][1], text1.index(res_typo[0][1]))
        res_d[text2] = (res_typo[1][0], res_typo[1][1], text2.index(res_typo[1][1]))
        return res_d

    return res_d


def error_identification(text_list, id=None):
    """
    查找text_list 中错误的那一个，主要针对poi
        错误类型有：倒序、同形、同音、多字少字、错别字

    :param text_list: [text1, text2, ...]
    :param id: text_list对应的id
    :return: dict， 如果找到错误，则返回错误相关信息，只返回一个错误，如果无错误，则返回空字典
    """

    # 如果文本数量大于10，则不处理
    if len(text_list) >= 10 or len(text_list) < 2:
        return {}
    # 全角和半角转换
    data_list_q2b = [strQ2B(subdu(str(s))) for s in text_list]
    # 去括号
    data_list_rmbkt = [re.sub(u"\(.*?\)|（.*?）|\{.*?\}|\[.*?\]|\<.*?\>", "", s) for s in data_list_q2b]
    # 去符号
    data_list_rmsymb = [re.sub("[\s+\.\!\/_, $%^*(+\"\')]|[+—－\-()?【】“”！，。？:：、~@#￥%……&*（）\|「」▏·`▪•۰・●⁺°～’\[\➕;〔〕《–‖﹢〖〗‘》［］◆❤×『\]』｡×\\\️=；²∙﹙′★◎〉─③ⅳ―☆㎡〇ⅲ⊂♡⑧℃⑤︱╮₂ⅴⅱ³»①〈╭✘ ※❥･﹚､ⅰ<>›ܶ│丨‧丶]", "", s) for s in data_list_rmbkt]
    # 繁体转简体
    data_list_simch = [fa.cht_2_chs(s) for s in data_list_rmsymb]
    # 全部转小写
    data_list = [s.lower() for s in data_list_simch]
    # 去除常见尾部
    data_list_rmtail = [rm_common_words(s, common_words) for s in data_list]
    data_list_res = [s for s in data_list_rmtail if s != '']
    # 如果重复文本，则不处理
    if len(set(data_list_res)) == 1:
        return {}
    data_list_rmrepeet = list(set(data_list))

    origin_texts = text_list
    origin2text = data_list

    if len(data_list_rmrepeet) < 2:
        return {}

    # 分别保存 倒序、同形、同音、多字少字、错字 的dict
    d_dict = find_disorder(data_list_rmrepeet)
    tx_dict = find_tongxing(data_list_rmrepeet)
    ty_dict = find_tongyin(data_list_rmrepeet)
    ds_dict, cz_dict = {}, {}
    # 两两遍历文本，分别判断是否存在对应错误
    for i in range(len(data_list_rmrepeet) - 1):
        for j in range(i + 1, len(data_list_rmrepeet)):
            if data_list_rmrepeet[i] != data_list_rmrepeet[j]:
                moreless_dict = find_moreless(data_list_rmrepeet[i], data_list_rmrepeet[j])
                typo_dict = find_typo(data_list_rmrepeet[i], data_list_rmrepeet[j])

                if len(moreless_dict) > 0:
                    for k, v in moreless_dict.items():
                        ds_dict[k] = v
                if len(typo_dict) > 0:
                    for k, v in typo_dict.items():
                        cz_dict[k] = v

    output_dict = {}

    output_dict['id'] = id     #数据id
    output_dict['type'] = ''   #错误类型
    output_dict['err'] = ''    #错误是否可以判断,可以判断为空,不可以判断则填入不好判断
    output_dict['wrong_text'] = ''     #错误的字
    output_dict['right_text'] = ''     #正确的字
    output_dict['right'] = ''    #认为正确的
    output_dict['origin_text'] = text_list             #原始数据


    # 倒序 > 同形 > 同音 > 多字少字 > 错别字
    if len(d_dict) > 0:
        res_dict = d_dict
        output_dict['type'] = '倒序'
    elif len(tx_dict) > 0:
        res_dict = tx_dict
        output_dict['type'] = '同形'
    elif len(ty_dict) > 0:
        res_dict = ty_dict
        output_dict['type'] = '同音'
    elif len(ds_dict) > 0:
        res_dict = ds_dict
        output_dict['type'] = '多字少字'
    elif len(cz_dict) > 0:
        res_dict = cz_dict
        output_dict['type'] = '错别字'
    else:
        res_dict = {}


    if len(res_dict) == 0:
        return res_dict
    
    # wrong_count_dict = {}
    # for text, wrong in res_dict.items():
    #
    #     #例子 {'丰巢快递柜': ('巢', '丰巢快', 0), '丰巢巢快递柜': ('巢', '丰巢巢快', 0)}
    #     wrong_span = wrong[1]
    #     for o_text in origin2text:
    #         if wrong_span in o_text:
    #             if wrong_span not in wrong_count_dict:
    #                 wrong_count_dict[wrong_span] = 0
    #             else:
    #                 wrong_count_dict[wrong_span] += 1
    #
    # final_dict = sorted(wrong_count_dict.items(),key=lambda x:x[1],reverse=False)

    wrong_count_dict = {}
    for o_text in origin2text:
        if o_text in res_dict:
            wrong_span = res_dict[o_text][1]
            if wrong_span not in wrong_count_dict:
                wrong_count_dict[wrong_span] = 0
            else:
                wrong_count_dict[wrong_span] += 1
    final_dict = sorted(wrong_count_dict.items(),key=lambda x:x[1],reverse=False)

    if len(final_dict) <= 1:
        return {}
    else:
        if len(final_dict) > 1:
            if final_dict[0][1] == final_dict[-1][1]:
                output_dict['err'] = '不好确定'    
        final_wrong_span = final_dict[0][0]
        final_right_span = final_dict[-1][0]

        # 修正包含关系
        if final_right_span in final_wrong_span:
            if final_dict[0][1] * 2  > final_dict[-1][1]:
                final_wrong_span,final_right_span = final_right_span,final_wrong_span

        # 找到错误的字
        if output_dict['type'] == '多字少字':
            for text, wrong in res_dict.items():
                if wrong[0] != '':
                    output_dict['wrong_text'] = wrong[0]
                    break

            if final_wrong_span in final_right_span:
                output_dict['type'] = '少字'
                output_dict['right_text'] = output_dict['wrong_text']
                output_dict['wrong_text'] = ''

            elif final_right_span in final_wrong_span:
                output_dict['type'] = '多字'
                output_dict['wrong_text'] = output_dict['wrong_text']
                output_dict['right_text'] = ''

            elif len(final_wrong_span) > len(final_right_span):
                output_dict['type'] = '多字'
                output_dict['wrong_text'] = output_dict['wrong_text']
                output_dict['right_text'] = ''
            else:
                output_dict['type'] = '少字' 
                output_dict['right_text'] = output_dict['wrong_text']
                output_dict['wrong_text'] = ''        

        else: 
            for text, wrong in res_dict.items():
                if res_dict[text][1] == final_wrong_span:
                    output_dict['wrong_text'] = res_dict[text][0]
                if res_dict[text][1] == final_right_span:
                    output_dict['right_text'] = res_dict[text][0]


        # 寻找最可能的poi
        res = {}
        for i,o in enumerate(origin2text):
            if final_right_span in o:
                if origin_texts[i] not in res:
                    res[origin_texts[i]] = 1
                else:    
                    res[origin_texts[i]] += 1

                
        res = sorted(res.items(),key=lambda x:x[1],reverse=True)

        output_dict['right'] = res[0][0]

    return output_dict

# ts = ["力枫酒店（松滋广银店）", "老枫酒店"]
# tres = error_identification(ts)
# print(tres)

def correction(datas):
    res = []
    for fidx, d in tqdm(enumerate(datas)):
        a_name = fa.strQ2B(str(d['a_name']).lower())
        b_name = fa.strQ2B(str(d['b_name']).lower())
        distance = d['distance']
        if float(distance) < 200:
            tres = error_identification([a_name, b_name])
            if len(tres) > 0:
                if tres['type'] == '多字' or tres['type'] == '少字':
                    wt = tres['wrong_text'] if tres['wrong_text'] != '' else tres['right_text']
                    if wt in a_name:
                        a_name = re.sub(wt, '', a_name)
                    else:
                        try:
                            wt_idx = b_name.index(wt)
                        except:
                            try:
                                wt_idx = fa.cht_2_chs(b_name).index(wt)
                            except:
                                wt_idx = 0
                                print(fa.cht_2_chs(b_name), wt)
                        if wt_idx == 0:
                            a_name = wt + a_name
                        elif wt_idx == len(b_name) - 1:
                            a_name = a_name + wt
                        else:
                            instr = b_name[wt_idx-1: wt_idx+2]
                            try:
                                replace_str = b_name[wt_idx-1] + b_name[wt_idx+1]
                                a_name = re.sub(replace_str, instr, a_name)
                            except:
                                pass
                            # print(d['id'], a_name, b_name)
                if tres['type'] == '同形' or tres['type'] == '同音' or tres['type'] == '倒序':
                    wt = tres['wrong_text']
                    rt = tres['right_text']
                    if wt in a_name:
                        a_name = re.sub(wt, rt, a_name)
                        # print(d['id'], a_name, b_name)
                    else:
                        a_name = re.sub(rt, wt, a_name)
                        # print(d['id'], a_name, b_name)
            else:
                a_name = fa.cht_2_chs(a_name)
                b_name = fa.cht_2_chs(b_name)
        d['a_name'] = a_name
        d['b_name'] = b_name
        res.append(d)
    return res













































































from fairies.read import (
    read,
    read_json,
    read_txt,
    read_npy
)

from fairies.write import (
    write_txt,
    write_npy
)

from fairies.classification_utils import (
    random_split_data,
    count_label,
    # split_data,
    # analysis_res
)

from fairies.nlp_utils import (
    label2id,
    is_chinese,
    find_lcs,
    long_substr,
    split_to_paragraph,
    split_to_sents,
    split_to_subsents,
    get_slide_window_text,
    get_cut_window_text
)

from fairies.nlp_jieba_utils import(
    jieba_init,
    jieba_add_words,
    jieba_cut,
    find_co_occurrence_word
)

from fairies.knowledge import(
    get_tongyin,
    get_tongxing,
    get_hanzi,
    get_stop_word
)

from fairies.nlp_clean_data import (
    removeLineFeed,
    cht_2_chs, # 繁体到简体
    chs_2_cht, # 简体到繁体
    strQ2B,
)


from navinfo_tool.rule_error_identification import (
    error_identification
)

from navinfo_tool.utils import (
    read_config,    # 读取配置文件
    check_and_creat_dir,    # 判断文件目录是否存在，文件目录不存在则创建目录
    getPolygonArea,    # 计算多边形面积
    get_bracketed_content,    # 获取文本中所有小括号中的内容组成的list
    rm_bracketed,    # 去除文本中的括号，包括括号中的内容
    rm_symbol,    # 去除文本中的所有符号
    getLCS,    # 获取最长公共序列
    read_csv,    # 读取csv文件， 可以返回为list或者dict，通过isdict=True设置
    write_csv,  # 将数组的内容写到csv中, 支持list或者dict两种数据格式
    read_excel,    # 读取excel文件，可以返回为list或者dict，通过isdict=True设置
    write_json,    # 将json数据写到json文件中，解决了一些数据类型报错问题
    write_excel,    # 将数组的内容写到excel中, 支持list或者dict两种数据格式
    compute_vecsimilar_one_2_one,    # 计算两个向量的相似度，需要维度相同
    compute_vecsimilar__one_2_many,    # 计算一个向量和多个向量的相似度，返回相似度最大的下标和对应的相似度
    compute_vecsimilar__many_2_many    # 计算多个向量和多个向量的相似度，返回第一个参数中每个相似度最大的下标和对应的相似度

)


end_words = [
    "日用厂",
    "外经委",
    "微波",
    "福利院",
    "省卫校",
    "老市",
    "面粉厂",
    "家属区",
    "老法院",
    "创业园",
    "指挥塔",
    "武装部",
    "中医院",
    "小区",
    "小卖部",
    "信用社",
    "椰子店",
    "信访局",
    "财政局",
    "美发店",
    "地税局",
    "公安局",
    "气象局",
    "彩票站",
    "县检察院",
    "检察院",
    "养生园",
    "供销社",
    "林业局",
    "省政府",
    "彩票店",
    "干休所",
    "地质局",
    "科技城",
    "公产房",
    "国家税务局",
    "地方税务局",
    "税务局",
    "广播电视台",
    "电视台",
    "民政局",
    "养发馆",
    "化肥厂",
    "五小组",
    "军休所",
    "边检站",
    "公路局",
    "食品厂",
    "派出所",
    "奶茶店",
    "物资局",
    "小木屋",
    "道班",
    "陶瓷",
    "老年公寓",
    "酒店式公寓",
    "酒店公寓",
    "出租公寓",
    "公寓",
    "狗肉店",
    "设计院",
    "夜市",
    "热科院",
    "小龙虾",
    "火柴厂",
    "公租房",
    "粮食局",
    "就业局",
    "美甲屋",
    "省市场局执法局",
    "供电局",
    "邮政局",
    "教育局",
    "理发店",
    "鲜虾味",
    "煤气站",
    "邮政",
    "宿舍楼",
    "防晒衣",
    "工行",
    "老市委",
    "警备区",
    "老一小",
    "电信局",
    "省检察",
    "地矿局",
    "鞋店",
    "廉租房",
    "农械厂",
    "管理委员会",
    "居民委员会",
    "村民委员会",
    "委员会",
    "工商所",
    "铸管厂",
    "机械厂",
    "危改办",
    "老镇府",
    "印刷厂",
    "女装店",
    "店铺",
    "老镇委",
    "档案局",
    "手机店",
    "电镀厂",
    "门诊部",
    "国土局",
    "水务局",
    "环卫局",
    "委党校",
    "部队",
    "生活区",
    "木材厂",
    "养老驿站",
    "驿站",
    "指定药店",
    "药店",
    "省团委",
    "幼儿园",
    "三建",
    "家属院",
    "陶瓷厂",
    "管理处",
    "人保",
    "镇政府",
    "车管所",
    "农科院",
    "老胶厂",
    "美缝店",
    "建设厅",
    "小卖铺",
    "房管所",
    "省高院",
    "省军区",
    "救助站",
    "美肤坊",
    "综合楼",
    "气象站",
    "安置楼",
    "仓库",
    "矿站",
    "交通厅",
    "县党校",
    "党校",
    "建行楼",
    "排灌站",
    "敬老院",
    "快递点",
    "老车站",
    "发廊店",
    "棚户区",
    "省体院",
    "一口楼",
    "水务厅",
    "农科所",
    "软件园",
    "宝贝店",
    "新二中",
    "原鸡场",
    "教工",
    "国税局",
    "台球吧",
    "修理店",
    "托老院",
    "百货摊",
    "陶瓷区",
    "司法局",
    "五金厂",
    "省体校",
    "保税区",
    "电信楼",
    "小卖店",
    "宿舍",
    "汽车生产工厂",
    "发动机工厂",
    "汽车工厂",
    "变速箱工厂",
    "汽车智能工厂",
    "加工厂",
    "消毒液工厂",
    "酒精工厂",
    "手套工厂",
    "口罩工厂",
    "隔离服工厂",
    "防护服工厂",
    "工厂",
    "餐店",
    "村委会",
    "福利厂",
    "供气站",
    "茶叶店",
    "林科所",
    "卫校",
    "照相馆",
    "冶金局",
    "农具厂",
    "汽车站",
    "修理厂",
    "修造厂",
    "畜牧局",
    "旅租",
    "牙科诊所",
    "口腔诊所",
    "诊所",
    "烧鸡坊",
    "种子行",
    "立案庭",
    "旅文局",
    "老地税",
    "商检局",
    "卫健委",
    "钢铁厂",
    "试飞楼",
    "交通局",
    "房管局",
    "中棉所",
    "老干局",
    "妇幼保健院",
    "文体局",
    "老粮所",
    "交通征稽所",
    "烟草局",
    "邮政快递",
    "环保局",
    "农业局",
    "水果市场",
    "药监局",
    "外贸局",
    "县法院",
    "法院",
    "边防支队",
    "新蓝山",
    "日作局",
    "市监局",
    "文明中",
    "工商局",
    "热作局",
    "商业银行",
    "24小时银行",
    "自助银行",
    "银行",
    "安监局",
    "城管局",
    "出入境检验检疫局",
    "大使馆",
    "党委",
    "地理信息局",
    "地震局",
    "公安分局",
    "分局",
    "改革局",
    "通信管理局",
    "无线电管理局",
    "管理局",
    "广电局",
    "规划局",
    "国防科技工业局",
    "国务院",
    "海关",
    "环境保护局",
    "机关事务局",
    "计生局",
    "纪检委",
    "监察局",
    "建设局",
    "经贸局",
    "科技局",
    "劳动局",
    "领事处",
    "领事馆",
    "旅游局",
    "贸易局",
    "南水北调办",
    "农机局",
    "签证处",
    "人大",
    "人民代表大会",
    "人事局",
    "商务局",
    "审计局",
    "市委",
    "水利局",
    "体育局",
    "统计局",
    "卫生局",
    "文化局",
    "物价局",
    "县委",
    "乡镇企业局",
    "烟草专卖局",
    "盐务局",
    "招商局",
    "政府副中心",
    "政协",
    "质监局",
    "国家税务总局",
    "总局",
    "车东站",
    "车西站",
    "车北站",
    "车南站",
    "交通枢纽",
    "磁悬浮",
    "轻轨站",
    "地铁站",
    "货运站",
    "高塔",
    "总部大厦",
    "商务大厦",
    "大厦",
    "百货大楼",
    "办公大楼",
    "总部大楼",
    "大楼",
    "高楼",
    "商业综合体",
    "综合体",
    "商业广场",
    "购物广场",
    "站前广场",
    "站广场",
    "中心广场",
    "广场",
    "写字楼",
    "秋裤",
    "金融中心",
    "商业地产",
    "汽车总装厂",
    "研发中心",
    "零部件厂",
    "发动机厂",
    "试验场",
    "试车场",
    "造车新势力车厂",
    "互联网汽车车厂",
    "无人车车厂",
    "智能汽车车厂",
    "新能源汽车车厂",
    "车厂",
    "充电桩",
    "智慧充电站",
    "智能充电站",
    "超级充电站",
    "充电站",
    "游园文化园",
    "生态园",
    "花园",
    "湿地公园",
    "世界地质公园",
    "国家地质公园",
    "地质公园",
    "森林公园",
    "海洋公园",
    "遗址公园",
    "购物公园",
    "公园",
    "会场",
    "会展中心",
    "活动中心",
    "展览中心",
    "会议中心",
    "港澳台到达",
    "港澳台出发",
    "国际机场",
    "机场",
    "t2航站楼",
    "国内到达",
    "国内出发",
    "国际到达",
    "国际出发",
    "直升机",
    "航站楼",
    "候机楼",
    "商务中心",
    "妇幼保健",
    "妇女儿童",
    "医学中心",
    "医馆",
    "卫生院",
    "卫生所",
    "三甲医院",
    "分院",
    "专科医院",
    "宠物医院",
    "宠物动物医院",
    "动物医院",
    "植物医院",
    "社区医院",
    "妇女儿童医院",
    "肿瘤医院",
    "骨科医院",
    "三级甲等医院",
    "医院",
    "西餐厅",
    "餐厅",
    "酒楼",
    "饭庄",
    "火车站",
    "客运站",
    "商业街",
    "商业中心",
    "aaaaa",
    "自然文化遗产",
    "自然风景区",
    "风景区",
    "旅游景区",
    "景区",
    "高尔夫",
    "网球俱乐部",
    "俱乐部",
    "羽毛球场",
    "网球场",
    "球场",
    "shoppingmall",
    "mall",
    "百货",
    "百货商场",
    "大卖场",
    "购物",
    "购物城",
    "购物街",
    "购物中心",
    "商场",
    "充换电站",
    "换电站",
    "快充站",
    "变电站",
    "充电",
    "充电堆",
    "充电塔",
    "野生动物园",
    "游园",
    "文化园",
    "展览馆",
    "车辆检测中心",
    "机动车检测中心",
    "机动车检测站",
    "机动车检测场",
    "高铁",
    "站房",
    "站入口",
    "站出口",
    "城际",
    "动车组",
    "城铁",
    "高速铁路",
    "城际铁路",
    "快速铁路",
    "铁路",
    "客专",
    "小火车",
    "新城",
    "商务区",
    "商贸城",
    "商品城",
    "物流城",
    "产业园",
    "文化区",
    "旅游区",
    "总部基地",
    "汽车制造基地",
    "影视基地",
    "训练基地",
    "培训基地",
    "露营基地",
    "产业基地",
    "工业基地",
    "基地",
    "度假区",
    "汽车城",
    "旧城",
    "美食街",
    "步行街",
    "地铁周边",
    "海洋世界",
    "海洋馆",
    "水上乐园",
    "大型游乐场",
    "大型游乐园",
    "路公交",
    "水上公交",
    "观光公交",
    "旅游公交",
    "快速公交",
    "公交",
    "公交线",
    "公交站",
    "线路",
    "观光巴士",
    "水上巴士",
    "旅游巴士",
    "有轨电车",
    "办公室",
    "省委",
    "驻办事处",
    "办事处",
    "区政府",
    "县政府",
    "旗政府",
    "乡政府",
    "政府",
    "研究所",
    "开发区",
    "学院",
    "大学",
    "学校",
    "四星酒店",
    "五星酒店",
    "乡村酒店",
    "商务酒店",
    "大酒店",
    "酒店",
    "超市",
    "房车制造企业",
    "企业",
    "旅游公司",
    "消毒液公司",
    "酒精公司",
    "手套公司",
    "口罩公司",
    "隔离服公司",
    "防护服公司",
    "空客公司",
    "科技股份有限公司",
    "有限公司",
    "科技股份公司",
    "股份公司",
    "科技公司",
    "公司",
    "集团",
    "品牌",
    "商城",
    "电影院",
    "连锁",
    "保险",
    "证券",
    "自助餐",
    "西餐馆",
    "餐馆",
    "小商品市场",
    "劳动力市场",
    "人才市场",
    "人力资源市场",
    "批发市场",
    "菜市场",
    "旧货市场",
    "二手车市场",
    "市场",
    "便利店",
    "门店",
    "餐饮",
    "茶楼",
    "连锁店",
    "加油站",
    "风景名胜区",
    "风景保护区",
    "景点",
    "商业区",
    "商贸中心",
    "商业城",
    "手机卖场",
    "卖场",
    "商厦",
    "欢乐世界",
    "商务楼",
    "金融科技中心",
    "总部城",
    "总部办公楼",
    "燃料电池汽车",
    "自动驾驶汽车",
    "新能源车",
    "新能源汽车",
    "汽车项目",
    "轮胎",
    "车企",
    "大饭店",
    "国际饭店",
    "饭店",
    "海鲜自助",
    "专家局",
    "生产力促进中心",
    "监察院",
    "新闻办",
    "港澳办",
    "方志办",
    "政府参事室",
    "政府合作交流办",
    "民防办",
    "政府外办",
    "影城",
    "汽车美容",
    "美容",
    "理发",
    "家政服务",
    "家电维修",
    "婚姻介绍所",
    "影楼",
    "婚庆",
    "西餐",
    "快餐",
    "饭馆",
    "食堂",
    "地方名吃",
    "小吃店",
    "烧麦",
    "小吃",
    "美食城",
    "龙抄手",
    "美食",
    "烤鸭店",
    "米粉",
    "公馆",
    "酒家",
    "酒馆",
    "食府",
    "菜馆",
    "酒吧",
    "咖啡厅",
    "咖啡馆",
    "咖啡屋",
    "咖啡",
    "冷饮",
    "茶馆",
    "服装厂",
    "贴合厂",
    "线缆厂",
    "橡胶厂",
    "纸箱厂",
    "工艺厂",
    "公路超限检测站",
    "超限超载检测站",
    "报纸",
    "报刊",
    "日报社",
    "杂志社",
    "出版社",
    "报社",
    "社区居委会",
    "商务会所",
    "商务港",
    "资料馆",
    "档案馆",
    "度假村",
    "极地馆",
    "水族馆",
    "剧院",
    "戏院",
    "音乐厅",
    "体育场",
    "体育馆",
    "图书馆",
    "美术馆",
    "博物馆",
    "纪念馆",
    "陈列馆",
    "文化馆",
    "科技馆",
    "电器城",
    "家电城",
    "大中电器",
    "苏宁电器",
    "国美电器",
    "电器",
    "影视中心",
    "影视传媒",
    "广播电台",
    "广播电视",
    "电视中心",
    "新闻中心",
    "电影制片厂",
    "电台",
    "遗址",
    "文化旅游",
    "文化街区",
    "旅游小镇",
    "旅游项目",
    "旅游文化",
    "观光园",
    "观光塔",
    "度假旅游",
    "天文馆",
    "少年宫",
    "陈列厅",
    "展示馆",
    "展馆",
    "博览园",
    "博物院",
    "陈列室",
    "文博",
    "群艺馆",
    "画院",
    "艺术馆",
    "书院",
    "分馆",
    "图书城",
    "养老院",
    "交警队",
    "湿地",
    "培训中心",
    "驻华国际组织",
    "国际组织",
    "联合国",
    "驻联络处",
    "驻华联络处",
    "联络处",
    "驻华联络部",
    "联络部",
    "使馆",
    "服务大厅",
    "人才服务中心",
    "人力资源服务中心",
    "金融服务中心",
    "服务中心",
    "服务厅",
    "展览厅",
    "会议厅",
    "交警大队",
    "大队",
    "公安处",
    "公安厅",
    "交管局",
    "交警",
    "交警支队",
    "巡警队",
    "支队",
    "中队",
    "总队",
    "阅览室",
    "书屋",
    "书房",
    "颐养院",
    "墓地",
    "公墓",
    "陵园",
    "厂矿",
    "工业区",
    "工业园",
    "汽车零部件",
    "座椅",
    "整车",
    "货车站",
    "缆车站",
    "车站",
    "综合交通",
    "交通综合场",
    "次枢纽",
    "训练中心",
    "城市值机厅",
    "航空",
    "急诊楼",
    "疫病预防控制中心",
    "防疫站",
    "疾病预防控制中心",
    "卫生院防保站",
    "兽医站",
    "防治所",
    "高速停车区",
    "高速服务区",
    "边检",
    "边防检查站",
    "综合枢纽",
    "客运枢纽",
    "机楼",
    "综合供能服务站",
    "磁浮",
    "轮渡",
    "港口",
    "渡口",
    "码头",
    "汽渡",
    "高速快轨",
    "加气站",
    "出站口",
    "入站口",
    "客运",
    "东站",
    "西站",
    "南站",
    "轻轨",
    "地铁",
    "11号线",
    "1号线",
    "12号线",
    "2号线",
    "13号线",
    "3号线",
    "14号线",
    "4号线",
    "15号线",
    "5号线",
    "16号线",
    "6号线",
    "7号线",
    "8号线",
    "9号线",
    "10号线",
    "号线",
    "二级公路收费站",
    "高速收费站",
    "普通公路收费站",
    "收费站",
    "货车停车场",
    "停车场",
    "云轨",
    "批发城",
    "交易中心",
    "实验中心",
    "研究院",
    "研究中心",
    "教课楼",
    "教学楼",
    "体大",
    "师大",
    "高职",
    "职专",
    "职校",
    "体校",
    "师范",
    "高校",
    "大专",
    "大学城",
    "新校区",
    "校区",
    "分校",
    "托儿所",
    "中专",
    "高级中学",
    "中学",
    "艺校",
    "小学",
    "驾校",
    "技校",
    "高中",
    "初中",
    "幼师",
    "职业技术",
    "美甲",
    "纹身",
    "美体",
    "洗衣店",
    "车保养",
    "保养",
    "摄影",
    "汽配",
    "汽车养护",
    "汽车用品",
    "棋牌",
    "网吧",
    "网咖",
    "福彩",
    "体彩",
    "博彩",
    "房产中介",
    "送水站",
    "房屋中介",
    "房产",
    "地产",
    "保洁",
    "家政",
    "时装屋",
    "服饰店",
    "服装店",
    "服装定制",
    "裁缝",
    "制衣",
    "养护馆",
    "婚姻",
    "婚姻介绍",
    "婚介",
    "婚纱",
    "数码冲印",
    "照相",
    "拍卖行",
    "典当行",
    "营业部",
    "期货",
    "旅行社",
    "速递",
    "快运",
    "物流",
    "快递",
    "支付点",
    "营业厅",
    "洗衣",
    "干洗",
    "足浴",
    "洗浴",
    "足道",
    "海滨浴场",
    "浴场",
    "浴池",
    "按摩",
    "足疗",
    "推拿",
    "足艺",
    "养生堂",
    "足疗馆",
    "养生会所",
    "发廊",
    "美发",
    "票务",
    "机票",
    "票务服务",
    "售票处",
    "订票点",
    "订票处",
    "送水",
    "水站",
    "知识产权事务所",
    "专利事务所",
    "审计事务所",
    "审计",
    "会计事务所",
    "律师事务所",
    "税务师事务所",
    "事务所",
    "鉴定中心",
    "司法鉴定所",
    "会计所",
    "律师办事厅",
    "律师税务所",
    "律师所",
    "法律咨询",
    "法律法规咨询处",
    "法律援助",
    "鉴定所",
    "法律服务",
    "安全鉴定",
    "劳务派遣",
    "检查中心",
    "体检中心",
    "齿科",
    "牙科",
    "口腔科",
    "垂钓",
    "渔场",
    "网络沙龙",
    "网络会所",
    "棋牌室",
    "出租房",
    "住宿",
    "二手车行",
    "车行",
    "汽车租赁",
    "体检",
    "自行车租赁",
    "租赁",
    "迪厅",
    "歌舞厅",
    "夜总会",
    "康乐宫",
    "健身房",
    "中介",
    "考点",
    "考场",
    "考试中心",
    "索道站",
    "地道站",
    "厕所",
    "卫生间",
    "殡仪馆",
    "火葬场",
    "出租车站出入口",
    "出租车停靠站",
    "商街",
    "商都",
    "金融街",
    "风情街",
    "滑雪大世界",
    "大世界",
    "零售",
    "茶具",
    "茶叶",
    "练歌房",
    "ktv",
    "面包房",
    "蛋糕房",
    "商店",
    "食杂店",
    "箱包",
    "服装",
    "景点售票",
    "景区售票",
    "土特产",
    "灯具",
    "宠物店",
    "花鸟鱼",
    "花卉",
    "保健品",
    "家居",
    "家具",
    "体育用品",
    "母婴用品",
    "图书",
    "眼镜",
    "烟酒",
    "室内装修",
    "建材",
    "五金",
    "文化用品",
    "玩具",
    "私人订制",
    "乐器",
    "洁具",
    "化妆品",
    "古玩",
    "摄影器材",
    "钟表",
    "珠宝",
    "汽车维修",
    "车维修",
    "摩托车",
    "电动车",
    "自行车",
    "旧货",
    "花圈寿衣",
    "殡仪",
    "中复",
    "迪信通",
    "电讯",
    "通讯",
    "音像",
    "报刊亭",
    "玩具城",
    "玩具世界",
    "儿童用品",
    "主题乐园",
    "玩具店",
    "儿童体验馆",
    "游泳馆",
    "早教",
    "儿童天地",
    "皮草城",
    "商业项目",
    "牛场",
    "羊场",
    "茶厂",
    "林场",
    "种鸡场",
    "育苗场",
    "鸭场",
    "鸡场",
    "花场",
    "牧场",
    "农场",
    "苗圃",
    "农技",
    "牧业",
    "农具",
    "农资",
    "畜牧",
    "屠宰场",
    "种业",
    "家教",
    "培训",
    "教育",
    "体验中心",
    "华园",
    "馨苑",
    "雅居",
    "景园",
    "华府",
    "华苑",
    "嘉苑",
    "豪庭",
    "名苑",
    "新苑",
    "佳园",
    "景苑",
    "雅苑",
    "佳苑",
    "华庭",
    "嘉园",
    "社区",
    "新村",
    "家园",
    "样板房",
    "安置房",
    "郦城",
    "诚园",
    "别墅",
    "豪宅",
    "新盘",
    "楼盘",
    "住宅区",
    "城中村",
    "分行",
    "支行",
    "合作社",
    "储蓄所",
    "金融理财中心",
    "atm网点",
    "营业网点",
    "分理处",
    "总行",
    "储蓄",
    "联社",
    "立体车库",
    "立体停车楼",
    "停车区",
    "二手车",
    "汽车服务",
    "汽车维护",
    "汽车销售",
    "汽车修理",
    "汽车修配",
    "汽贸汽修",
    "汽配商行",
    "充电场站",
    "充电终端",
    "换电箱",
    "加电站",
    "循道新能源",
    "检测场",
    "检测中心",
    "检测站",
    "汽车装潢",
    "租车",
    "律师服务站",
    "商务会馆",
    "养生馆",
    "娱乐会所",
    "会所",
    "门诊",
    "社区服务站",
    "保健院",
    "消协",
    "计生协",
    "工商联合会",
    "学会",
    "科协",
    "残联",
    "文联",
    "妇联",
    "协会",
    "工会",
    "社区卫生",
    "社区医疗",
    "纪念碑",
    "旧居",
    "故居",
    "旧址",
    "提货点",
    "配送站",
    "保龄球馆",
    "垂钓园",
    "会馆",
    "球會",
    "练习场",
    "球会",
    "滑雪场",
    "滑雪馆",
    "冰雪嘉年华",
    "剧场",
    "采摘园",
    "农家乐",
    "庄园",
    "农庄",
    "山庄",
    "跑马场",
    "赛马场",
    "水下世界",
    "体育中心",
    "场馆",
    "篮球馆",
    "运动场",
    "文体中心",
    "游泳池",
    "羽毛球馆",
    "羽球中心",
    "网球馆",
    "温泉",
    "浴室",
    "水上世界",
    "游乐园",
    "游乐场",
    "防保站",
    "邮政所",
    "邮政支局",
    "邮局",
    "影视城",
    "影院",
    "自然保护区",
    "冰雪场",
    "健身",
    "康乐",
    "电玩城",
    "风景名胜",
    "溜冰",
    "滑冰",
    "露营地",
    "房车营地",
    "农家院",
    "赛狗场",
    "赛狗会",
    "赛马会",
    "赛马",
    "海底世界",
    "网球中心",
    "娱乐城",
    "演艺",
    "舞台",
    "二人转",
    "书场",
    "相声",
    "戏曲",
    "戏馆",
    "戏剧",
    "文化宫",
    "戏楼",
    "艺术中心",
    "剧团",
    "马戏",
    "戏台",
    "皮影",
    "演播厅",
    "文化交流中心",
    "儿童乐园",
    "冒险乐园",
    "星级",
    "疗养院",
    "政府部门",
    "机关部门",
    "国税",
    "国地税",
    "地税",
    "税务机构",
    "税务新机构",
    "监察委",
    "联合国驻华",
    "宾馆",
    "别院",
    "度假中心",
    "养生苑",
    "养生中心",
    "疗养中心",
    "渡假村",
    "贵宾楼",
    "国际精品",
    "国际中心",
    "商旅",
    "山荘",
    "颐舍",
    "客栈",
    "客舍",
    "旅店",
    "旅社",
    "旅舍",
    "旅馆",
    "招待所",
    "游艇会",
    "清真寺",
    "伊斯兰教",
    "基督教",
    "道观",
    "文工团",
    "歌舞团",
    "艺术团",
    "杂技团",
    "合唱团",
    "舞团",
    "乐团",
    "混合遗产",
    "双重遗产",
    "自然与文化复合遗产",
    "复合遗产",
    "文化遗产",
    "自然遗产",
    "世界遗产",
    "新干线",
    "隧道",
    "隧桥",
    "跨线桥",
    "公铁桥",
    "桥梁",
    "斜拉桥",
    "悬索桥",
    "箱包专柜",
    "服装专柜",
    "消毒液厂",
    "酒精厂",
    "手套厂",
    "口罩厂",
    "隔离服厂",
    "防护服厂",
    "4s店",
    "旅游",
    "箱包厂",
    "药房",
    "药店列表",
    "防疫指挥中心",
    "防疫指挥部",
    "科技园",
    "物流园",
    "科技示范园",
    "物流中心",
    "创业中心",
    "快递柜",
    "智能柜",
    "自提柜",
    "汽车装饰",
    "装饰",
    "工作室",
    "画室",
    "中心",
    "经营部"
]



#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='navinfo_tool',
    version='0.1.3',
    description=(
        'utils for nlp'
    ),
    author='navinfo_nlp',
    author_email='navinfo_nlp@163.com',
    license='Apache License 2.0',
    packages=find_packages(),
    install_requires=[
        'xlrd==1.2.0',
        'jieba',
        'xlwt',
        'xlutils',
        'matplotlib',
        'sklearn',
        'pandas',
        'fairies',
        'configparser',
        'xpinyin==0.7.6',
        'xlsxwriter==3.0.1',
        'tqdm'
    ],
)
